//Source file: ConfPolicyType.java
//Date: July 2003
//Conference Call Control Interfaces and Data Types for ETSI ES 202 915-04-2 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-04-2 v5.1.0

package org.csapi.jr.se.cc.cccs;

/**
 * Defines policy type for the conference.<br>
 * If undefined the parlay gateway will select an appropriate default.<br>
 * If a mono media conference policy is specified for a multi-media conference, the parlay gateway will select appropriate defaults for the multi-media policy items.<br>
 * If a mulit-media policy is selected for a mono-media (voice-only) conference, the multi-meda conference items will be ignored.
 * 
 */
public final class ConfPolicyType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static ConfPolicyType[] _array = new ConfPolicyType[_size];

    /**
     * undefined
     */
    public static final int _CONFERENCE_POLICY_UNDEFINED =  0;
    public static final ConfPolicyType CONFERENCE_POLICY_UNDEFINED = new ConfPolicyType(_CONFERENCE_POLICY_UNDEFINED);

    /**
     * CCCS - monomedia conference policy
     */
    public static final int _CONFERENCE_POLICY_MONOMEDIA =  1;
    public static final ConfPolicyType CONFERENCE_POLICY_MONOMEDIA = new ConfPolicyType(_CONFERENCE_POLICY_MONOMEDIA);

    /**
     * MMCCS - mulitmedia conference policy
     */
    public static final int _CONFERENCE_POLICY_MULTIMEDIA =  2;
    public static final ConfPolicyType CONFERENCE_POLICY_MULTIMEDIA = new ConfPolicyType(_CONFERENCE_POLICY_MULTIMEDIA);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the ConfPolicyType object
     */
    public String toString() {
        switch (_value) {
            case _CONFERENCE_POLICY_UNDEFINED:
                return "CONFERENCE_POLICY_UNDEFINED";
            case _CONFERENCE_POLICY_MONOMEDIA:
                return "CONFERENCE_POLICY_MONOMEDIA";
            case _CONFERENCE_POLICY_MULTIMEDIA:
                return "CONFERENCE_POLICY_MULTIMEDIA";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ConfPolicyType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private ConfPolicyType(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }

        if(!(o instanceof ConfPolicyType)) {
            return false;
        }

        ConfPolicyType confPolicyType = ( ConfPolicyType)o; 
        if(!(this.getValue() == confPolicyType.getValue())) {
            return false;
        }
    
        if (this.hashCode() != confPolicyType.hashCode()) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        return 1;
    }

} // ConfPolicyType

