//Source file: VideoHandlingType.java
//Date: July 2003
//Conference Call Control Interfaces and Data Types for ETSI ES 202 915-04-2 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-04-2 v5.1.0


package org.csapi.jr.se.cc.cccs;

/**
 * Defines how video should be handled in the conference.
 *
 */
public final class VideoHandlingType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static VideoHandlingType[] _array = new VideoHandlingType[_size];

    /**
     * Video is switched automatically based on audio output of the speaker
     */
    public static final int _SWITCHED_VIDEO_VOICE_CONTROLLED =  0;
    public static final VideoHandlingType SWITCHED_VIDEO_VOICE_CONTROLLED = new VideoHandlingType(_SWITCHED_VIDEO_VOICE_CONTROLLED);

    /**
     * Video is switched, chair determines the speaker
     */
    public static final int _SWITCHED_VIDEO_CHAIR_CONTROLLED =  1;
    public static final VideoHandlingType SWITCHED_VIDEO_CHAIR_CONTROLLED = new VideoHandlingType(_SWITCHED_VIDEO_CHAIR_CONTROLLED);

    /**
     * Video is mixed, no special treatement of speaker
     */
    public static final int _MIXED_VIDEO =  2;
    public static final VideoHandlingType MIXED_VIDEO = new VideoHandlingType(_MIXED_VIDEO);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the VideoHandlingType object
     */
    public String toString() {
        switch (_value) {
            case _SWITCHED_VIDEO_VOICE_CONTROLLED:
                return "SWITCHED_VIDEO_VOICE_CONTROLLED";
            case _SWITCHED_VIDEO_CHAIR_CONTROLLED:
                return "SWITCHED_VIDEO_CHAIR_CONTROLLED";
            case _MIXED_VIDEO:
                return "MIXED_VIDEO";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static VideoHandlingType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private VideoHandlingType(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }

        if(!(o instanceof VideoHandlingType)) {
            return false;
        }

        VideoHandlingType videoHandlingType = ( VideoHandlingType)o; 
        if(!(this.getValue() == videoHandlingType.getValue())) {
            return false;
        }
    
        if (this.hashCode() != videoHandlingType.hashCode()) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        return 1;
    }

} // VideoHandlingType

